#
# spec file for package ghc-semigroups
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name semigroups
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.20
Release:        2.5
Summary:        Anything that associates
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
In mathematics, a semigroup is an algebraic structure consisting of a set
together with an associative binary operation. A semigroup generalizes a monoid
in that there might not exist an identity element. It also (originally)
generalized a group (a monoid with all inverses) to a type where every element
did not have to have an inverse, thus the name semigroup.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Nov 16 2021 psimons@suse.com
- Update semigroups to version 0.20.
  0.20 [2021.11.15]
  - ----------------
  * Support `hashable-1.4`. The `Hashable1` instances added in 0.19.2
    are removed for all types except `NonEmpty`, in accordance with the
    corresponding changes from `hashable-1.4`.
* Mon Nov  1 2021 psimons@suse.com
- Update semigroups to version 0.19.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Sep  3 2021 psimons@suse.com
- Update semigroups to version 0.19.2.
  0.19.2 [2021.08.30]
  - ------------------
  * Backport `Hashable1` instances for `NonEmpty`, `Min`, `Max`, `First`, `Last`,
    `WrappedMonoid`, and `Option`.
* Wed Jul 28 2021 psimons@suse.com
- Update semigroups to version 0.19.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Aug 28 2019 psimons@suse.com
- Update semigroups to version 0.19.1.
  0.19.1 [2019.08.27]
  - ------------------
  * Add `GenericSemigroupMonoid`, an adapter newtype suitable for `DerivingVia`,
    to `Data.Semigroup.Generic`.
  * Work around a bug related to the backported `Generic(1)` instances in this
    package (that could only be triggered on GHC 7.2 or 7.4) in which the
    hand-written `Datatype`, `Constructor`, and `Selector` instances for internal
    data types could overlap with GHC-generated instances.
* Sat May 11 2019 psimons@suse.com
- Update semigroups to version 0.19.
  0.19 [2019.05.10]
  - ----------------
  * The `(<>)` method of the backported `Semigroup` class no longer has a default
    implementation in terms of `mappend`. This mirrors the `Data.Semigroup` API
    that was introduced in `base-4.9`. This is a breaking change for any
    `Semigroup` instances that are defined in tandem with versions of `base`
    older than 4.9.
  * Make the backported `Hashable Arg` instance reflect its respective variants
    in the `hashable` package. In `hashable-1.3`, the `Hashable Arg` instance
    only hashes the first argument, lest equal values have different hashes.
  * Backport the `Lift (NonEmpty a)` instance introduced in
    `template-haskell-2.15.0.0`.
  * `Data.List.NonEmpty` is now unconditionally `Trustworthy`.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update semigroups to version 0.18.5.
  0.18.5 [2018.07.02]
  - ------------------
  * Use a more efficient `sconcat` for the `Semigroup` instances for strict and
    lazy `ByteString`.
* Mon May 14 2018 psimons@suse.com
- Update semigroups to version 0.18.4.
  * Backport `Semigroup` instances for `Data.Ord.Down` and strict
    `ST`, which were added in `base-4.11`.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.18.3.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.18.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.18.1 revision 1 with cabal2obs.
* Fri Jan 29 2016 mimi.vx@gmail.com
- update to 0.18.1
  * Add the missing instance for Data.Binary.Builder.Builder.
* Wed Dec 23 2015 mimi.vx@gmail.com
- update to 0.18.0.1
- dropped nats.cabal.patch
  * Removed the partial functions words, unwords, lines, unlines
  * Added support for base-4.9
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.17.0.1
  * Fixed the @since annotations
  * Added groupWith, groupAllWith, groupWith1, groupAllWith1
  * Renamed sortOn to sortWith to match the "Comprehensive comprehensions" paper and
    TransformListComp extension.
  * Add Semigroup instances for Alt, Void, Proxy and Tagged
  * Add Num instances for Min and Max
  * Removed times1p in favor of stimes.
* Thu May 14 2015 mimi.vx@gmail.com
- add nats.cabal.patch -- remove ghc-nats from deps
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 0.16.2.2
  * Added `genericMappend` and supporting `GSemigroup` class for generically deriving Semigroup instances.
  * Added `Arg a b` which only compares for equality/order on its first argument, which
    can be used to compute `argmin` and `argmax`.
  * Add `Bifunctor` `Arg` instance to avoid orphans for GHC 7.10+.
  * Added missing `Data.Monoid.Generic` module to source control.
  * Added `Semigroup` instances for various Builder constructions in `text` and `bytestring` where available.
  * Added `MonadFix` and `MonadPlus` instances for `NonEmpty`.
  * `times1p` and `timesN` are now reduced to accepting only a `Natural` argument.
    `Whole` doesn't exist in GHC 7.10's Numeric.Natural, and `nats` version 1 has removed support for the class.
* Thu Nov 13 2014 peter.trommler@ohm-hochschule.de
- update to 0.15.4
  * compatibility with Haskell Platform 2014.2.0.0
  * no upstream changelog
* Thu Mar 27 2014 sbahling@suse.com
-  Correct package license (BSD-2-Clause)
* Mon Oct 28 2013 sbahling@suse.com
- Update to version 0.11
  Use cabal-rpm specfile template
* Thu Jun  7 2012 herbert@graeber-clan.de
- fix arch
* Thu Jun  7 2012 herbert@graeber-clan.de
- update for haskell platform 2012.2.0.0
  spec file template generated by cabal2spec-0.25.5
* Sat Jan 21 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
